.modal-close.svelte-2nujim{-moz-appearance:none;-webkit-appearance:none;background-color:rgba(10, 10, 10, 0.2);border:none;border-radius:290486px;cursor:pointer;pointer-events:auto;display:inline-block;flex-grow:0;flex-shrink:0;font-size:0;height:20px;max-height:20px;max-width:20px;min-height:20px;min-width:20px;outline:none;position:relative;vertical-align:top;width:20px}.modal-close.svelte-2nujim::before,.modal-close.svelte-2nujim::after{background-color:white;content:"";display:block;left:50%;position:absolute;top:50%;transform:translateX(-50%) translateY(-50%) rotate(45deg);transform-origin:center center}.modal-close.svelte-2nujim::before{height:2px;width:50%}.modal-close.svelte-2nujim::after{height:50%;width:2px}.modal-close.svelte-2nujim:hover,.modal-close.svelte-2nujim:focus{background-color:rgba(10, 10, 10, 0.3)}.modal-close.svelte-2nujim:active{background-color:rgba(10, 10, 10, 0.4)}.is-large.modal-close.svelte-2nujim{height:32px;max-height:32px;max-width:32px;min-height:32px;min-width:32px;width:32px}.modal.svelte-2nujim{align-items:center;display:none;flex-direction:column;justify-content:center;overflow:hidden;position:fixed;z-index:40}.modal.is-active.svelte-2nujim{display:flex}.modal-background.svelte-2nujim{background-color:rgba(10, 10, 10, 0.86)}.modal-close.svelte-2nujim{background:none;height:40px;position:fixed;right:20px;top:20px;width:40px}