.breadcrumb.svelte-g89v9p.svelte-g89v9p{font-size:1rem;white-space:nowrap;margin-bottom:1.5rem}.breadcrumb.svelte-g89v9p a.svelte-g89v9p{align-items:center;display:flex;justify-content:center;padding:0 0.75em}.breadcrumb.svelte-g89v9p a.svelte-g89v9p:hover{color:#363636}.breadcrumb.svelte-g89v9p li.svelte-g89v9p{align-items:center;display:flex}.breadcrumb.svelte-g89v9p li:first-child a.svelte-g89v9p{padding-left:0}.breadcrumb.svelte-g89v9p li.is-active a.svelte-g89v9p{color:#363636;cursor:default;pointer-events:none}.breadcrumb li+li.svelte-g89v9p.svelte-g89v9p::before{color:#b5b5b5;content:"\0002f"}.breadcrumb.svelte-g89v9p ul.svelte-g89v9p{align-items:flex-start;display:flex;flex-wrap:wrap;justify-content:flex-start}.breadcrumb.has-arrow-separator li+li.svelte-g89v9p.svelte-g89v9p::before{content:"\02192"}.breadcrumb.has-bullet-separator li+li.svelte-g89v9p.svelte-g89v9p::before{content:"\02022"}.breadcrumb.has-dot-separator li+li.svelte-g89v9p.svelte-g89v9p::before{content:"\000b7"}.breadcrumb.has-succeeds-separator li+li.svelte-g89v9p.svelte-g89v9p::before{content:"\0227B"}