.input.svelte-xy8puh.svelte-xy8puh{-moz-appearance:none;-webkit-appearance:none;align-items:center;border:1px solid transparent;border-radius:4px;box-shadow:none;display:inline-flex;font-size:1rem;height:2.5em;justify-content:flex-start;line-height:1.5;padding-bottom:calc(0.5em - 1px);padding-left:calc(0.75em - 1px);padding-right:calc(0.75em - 1px);padding-top:calc(0.5em - 1px);position:relative;vertical-align:top}.input.is-rounded.svelte-xy8puh.svelte-xy8puh{border-radius:290486px;padding-left:calc(calc(0.75em - 1px) + 0.375em);padding-right:calc(calc(0.75em - 1px) + 0.375em)}.input.svelte-xy8puh.svelte-xy8puh{background-color:white;border-color:#dbdbdb;border-radius:4px;color:#363636}.input.svelte-xy8puh.svelte-xy8puh::-moz-placeholder{color:rgba(54, 54, 54, 0.3)}.input.svelte-xy8puh.svelte-xy8puh::-webkit-input-placeholder{color:rgba(54, 54, 54, 0.3)}.input.svelte-xy8puh.svelte-xy8puh:-moz-placeholder{color:rgba(54, 54, 54, 0.3)}.input.svelte-xy8puh.svelte-xy8puh:-ms-input-placeholder{color:rgba(54, 54, 54, 0.3)}.input.svelte-xy8puh.svelte-xy8puh:hover{border-color:#b5b5b5}.input.svelte-xy8puh.svelte-xy8puh:focus{border-color:#3273dc;box-shadow:0 0 0 0.125em rgba(50, 115, 220, 0.25)}.input.svelte-xy8puh.svelte-xy8puh{box-shadow:inset 0 0.0625em 0.125em rgba(10, 10, 10, 0.05);max-width:100%;width:100%}.field.svelte-xy8puh.svelte-xy8puh:not(:last-child){margin-bottom:0.75rem}.label.svelte-xy8puh.svelte-xy8puh{color:#363636;display:block;font-size:1rem;font-weight:700}.label.svelte-xy8puh.svelte-xy8puh:not(:last-child){margin-bottom:0.5em}.control.svelte-xy8puh.svelte-xy8puh{box-sizing:border-box;clear:both;font-size:1rem;position:relative;text-align:left}.select.svelte-xy8puh.svelte-xy8puh:not(.is-multiple):not(.is-loading)::after{border:3px solid transparent;border-radius:2px;border-right:0;border-top:0;content:" ";display:block;height:0.625em;margin-top:-0.4375em;pointer-events:none;position:absolute;top:50%;transform:rotate(-45deg);transform-origin:center;width:0.625em}.select.svelte-xy8puh select.svelte-xy8puh{-moz-appearance:none;-webkit-appearance:none;align-items:center;border:1px solid transparent;border-radius:4px;box-shadow:none;display:inline-flex;font-size:1rem;height:2.5em;justify-content:flex-start;line-height:1.5;padding-bottom:calc(0.5em - 1px);padding-left:calc(0.75em - 1px);padding-right:calc(0.75em - 1px);padding-top:calc(0.5em - 1px);position:relative;vertical-align:top}.field.is-grouped.svelte-xy8puh.svelte-xy8puh{display:flex;justify-content:flex-start}.field.is-grouped.svelte-xy8puh>.control.svelte-xy8puh{flex-shrink:0}.field.is-grouped.svelte-xy8puh>.control.svelte-xy8puh:not(:last-child){margin-bottom:0;margin-right:0.75rem}.field.is-grouped.is-grouped-multiline.svelte-xy8puh.svelte-xy8puh{flex-wrap:wrap}.field.is-grouped.is-grouped-multiline.svelte-xy8puh>.control.svelte-xy8puh:last-child,.field.is-grouped.is-grouped-multiline.svelte-xy8puh>.control.svelte-xy8puh:not(:last-child){margin-bottom:0.75rem}.field.is-grouped.is-grouped-multiline.svelte-xy8puh.svelte-xy8puh:last-child{margin-bottom:-0.75rem}.field.is-grouped.is-grouped-multiline.svelte-xy8puh.svelte-xy8puh:not(:last-child){margin-bottom:0}.field.has-addons .control.svelte-xy8puh:not(:first-child):not(:last-child) .button.svelte-xy8puh,.field.has-addons .control.svelte-xy8puh:not(:first-child):not(:last-child) .input.svelte-xy8puh{border-radius:0}.field.has-addons .control.svelte-xy8puh:first-child:not(:only-child) .button.svelte-xy8puh,.field.has-addons .control.svelte-xy8puh:first-child:not(:only-child) .input.svelte-xy8puh{border-bottom-right-radius:0;border-top-right-radius:0}.field.has-addons .control.svelte-xy8puh:last-child:not(:only-child) .button.svelte-xy8puh,.field.has-addons .control.svelte-xy8puh:last-child:not(:only-child) .input.svelte-xy8puh{border-bottom-left-radius:0;border-top-left-radius:0}.field.has-addons .control.svelte-xy8puh .button.svelte-xy8puh:not([disabled]):hover,.field.has-addons .control.svelte-xy8puh .input.svelte-xy8puh:not([disabled]):hover{z-index:2}.field.has-addons .control.svelte-xy8puh .button.svelte-xy8puh:not([disabled]):focus,.field.has-addons .control.svelte-xy8puh .button.svelte-xy8puh:not([disabled]):active,.field.has-addons .control.svelte-xy8puh .input.svelte-xy8puh:not([disabled]):focus,.field.has-addons .control.svelte-xy8puh .input.svelte-xy8puh:not([disabled]):active{z-index:3}.field.has-addons .control.svelte-xy8puh .button.svelte-xy8puh:not([disabled]):focus:hover,.field.has-addons .control.svelte-xy8puh .button.svelte-xy8puh:not([disabled]):active:hover,.field.has-addons .control.svelte-xy8puh .input.svelte-xy8puh:not([disabled]):focus:hover,.field.has-addons .control.svelte-xy8puh .input.svelte-xy8puh:not([disabled]):active:hover{z-index:4}.hovering.svelte-xy8puh.svelte-xy8puh{border:1px solid orange}.hovering.svelte-xy8puh .svelte-xy8puh{pointer-events:none}.basket.svelte-xy8puh.svelte-xy8puh{min-height:24px}